@@ -4,7 +4,7 @@ use File::Basename;
 use Mojo::Util qw(class_to_file class_to_path slurp);
 use POSIX qw(strftime);
 
-our $VERSION = '0.3.0';
+our $VERSION = '0.3.1';
 
 has description => 'Generate CallBackery web application directory structure.';
 has usage => sub { shift->extract_usage };
@@ -72,7 +72,7 @@ EOF
             email => $email,
             fullName => $fullName,
             userName => $userName,
-            date => strftime('%Y-%M-%D',localtime(time)),
+            date => strftime('%Y-%m-%d',localtime(time)),
         });
     }
 
